@@ -5,54 +5,58 @@ import { Role, OrgRole } from 'app/types';
 
 import { RolePickerInput } from './RolePickerInput';
 import { RolePickerMenu } from './RolePickerMenu';
-import { MENU_MAX_HEIGHT, ROLE_PICKER_WIDTH } from './constants';
+import { MENU_MAX_HEIGHT, ROLE_PICKER_SUBMENU_MIN_WIDTH, ROLE_PICKER_WIDTH } from './constants';
 
 export interface Props {
-  builtInRole?: OrgRole;
+  basicRole?: OrgRole;
   appliedRoles: Role[];
   roleOptions: Role[];
-  builtInRoles?: Record<string, Role[]>;
   isLoading?: boolean;
   disabled?: boolean;
-  builtinRolesDisabled?: boolean;
-  showBuiltInRole?: boolean;
+  basicRoleDisabled?: boolean;
+  showBasicRole?: boolean;
   onRolesChange: (newRoles: Role[]) => void;
-  onBuiltinRoleChange?: (newRole: OrgRole) => void;
+  onBasicRoleChange?: (newRole: OrgRole) => void;
   canUpdateRoles?: boolean;
+  /**
+   * Set {@link RolePickerMenu}'s button to display either `Apply` (apply=true) or `Update` (apply=false)
+   */
   apply?: boolean;
+  maxWidth?: string | number;
 }
 
 export const RolePicker = ({
-  builtInRole,
+  basicRole,
   appliedRoles,
   roleOptions,
   disabled,
   isLoading,
-  builtinRolesDisabled,
-  showBuiltInRole,
+  basicRoleDisabled,
+  showBasicRole,
   onRolesChange,
-  onBuiltinRoleChange,
+  onBasicRoleChange,
   canUpdateRoles = true,
   apply = false,
+  maxWidth = ROLE_PICKER_WIDTH,
 }: Props): JSX.Element | null => {
   const [isOpen, setOpen] = useState(false);
   const [selectedRoles, setSelectedRoles] = useState<Role[]>(appliedRoles);
-  const [selectedBuiltInRole, setSelectedBuiltInRole] = useState<OrgRole | undefined>(builtInRole);
+  const [selectedBuiltInRole, setSelectedBuiltInRole] = useState<OrgRole | undefined>(basicRole);
   const [query, setQuery] = useState('');
   const [offset, setOffset] = useState({ vertical: 0, horizontal: 0 });
   const ref = useRef<HTMLDivElement>(null);
 
   useEffect(() => {
-    setSelectedBuiltInRole(builtInRole);
+    setSelectedBuiltInRole(basicRole);
     setSelectedRoles(appliedRoles);
-  }, [appliedRoles, builtInRole]);
+  }, [appliedRoles, basicRole, onBasicRoleChange]);
 
   useEffect(() => {
     const dimensions = ref?.current?.getBoundingClientRect();
     if (!dimensions || !isOpen) {
       return;
     }
-    const { bottom, top, left, right } = dimensions;
+    const { bottom, top, left, right, width: currentRolePickerWidth } = dimensions;
     const distance = window.innerHeight - bottom;
     const offsetVertical = bottom - top + 10; // Add extra 10px to offset to account for border and outline
     const offsetHorizontal = right - left;
@@ -60,10 +64,22 @@ export const RolePicker = ({
     let vertical = -offsetVertical;
 
     if (distance < MENU_MAX_HEIGHT + 20) {
-      vertical = offsetVertical;
+      // Off set to display the role picker menu at the bottom of the screen
+      // without resorting to scroll the page
+      vertical = 50 + (MENU_MAX_HEIGHT - distance) - offsetVertical;
     }
 
-    if (window.innerWidth - right < ROLE_PICKER_WIDTH) {
+    /*
+     * This expression calculates whether there is enough place
+     * on the right of the RolePicker input to show/fit the role picker menu and its sub menu AND
+     * whether there is enough place under the RolePicker input to show/fit
+     * both (the role picker menu and its sub menu) aligned to the left edge of the input.
+     * Otherwise, it aligns the role picker menu to the right.
+     */
+    if (
+      window.innerWidth - right < currentRolePickerWidth &&
+      currentRolePickerWidth < 2 * ROLE_PICKER_SUBMENU_MIN_WIDTH
+    ) {
       horizontal = offsetHorizontal;
     }
 
@@ -85,8 +101,8 @@ export const RolePicker = ({
     setOpen(false);
     setQuery('');
     setSelectedRoles(appliedRoles);
-    setSelectedBuiltInRole(builtInRole);
-  }, [appliedRoles, builtInRole]);
+    setSelectedBuiltInRole(basicRole);
+  }, [appliedRoles, basicRole]);
 
   // Only call onClose if menu is open. Prevent unnecessary calls for multiple pickers on the page.
   const onClickOutside = () => isOpen && onClose();
@@ -103,13 +119,13 @@ export const RolePicker = ({
     setSelectedRoles(roles);
   };
 
-  const onBuiltInRoleSelect = (role: OrgRole) => {
+  const onBasicRoleSelect = (role: OrgRole) => {
     setSelectedBuiltInRole(role);
   };
 
   const onUpdate = (newRoles: Role[], newBuiltInRole?: OrgRole) => {
-    if (onBuiltinRoleChange && newBuiltInRole && newBuiltInRole !== builtInRole) {
-      onBuiltinRoleChange(newBuiltInRole);
+    if (onBasicRoleChange && newBuiltInRole && newBuiltInRole !== basicRole) {
+      onBasicRoleChange(newBuiltInRole);
     }
     if (canUpdateRoles) {
       onRolesChange(newRoles);
@@ -138,10 +154,17 @@ export const RolePicker = ({
   }
 
   return (
-    <div data-testid="role-picker" style={{ position: 'relative', width: ROLE_PICKER_WIDTH }} ref={ref}>
+    <div
+      data-testid="role-picker"
+      style={{
+        position: 'relative',
+        maxWidth,
+      }}
+      ref={ref}
+    >
       <ClickOutsideWrapper onClick={onClickOutside}>
         <RolePickerInput
-          builtInRole={selectedBuiltInRole}
+          basicRole={selectedBuiltInRole}
           appliedRoles={selectedRoles}
           query={query}
           onQueryChange={onInputChange}
@@ -149,20 +172,20 @@ export const RolePicker = ({
           onClose={onClose}
           isFocused={isOpen}
           disabled={disabled}
-          showBuiltInRole={showBuiltInRole}
+          showBasicRole={showBasicRole}
         />
         {isOpen && (
           <RolePickerMenu
             options={getOptions()}
-            builtInRole={selectedBuiltInRole}
+            basicRole={selectedBuiltInRole}
             appliedRoles={appliedRoles}
-            onBuiltInRoleSelect={onBuiltInRoleSelect}
+            onBasicRoleSelect={onBasicRoleSelect}
             onSelect={onSelect}
             onUpdate={onUpdate}
             showGroups={query.length === 0 || query.trim() === ''}
-            builtinRolesDisabled={builtinRolesDisabled}
-            showBuiltInRole={showBuiltInRole}
-            updateDisabled={builtinRolesDisabled && !canUpdateRoles}
+            basicRoleDisabled={basicRoleDisabled}
+            showBasicRole={showBasicRole}
+            updateDisabled={basicRoleDisabled && !canUpdateRoles}
             apply={apply}
             offset={offset}
           />
