@@ -2,8 +2,7 @@ import { render, waitFor, within, screen } from '@testing-library/react';
 import userEvent from '@testing-library/user-event';
 import { setupServer } from 'msw/node';
 import React from 'react';
-import { Provider } from 'react-redux';
-import { Router } from 'react-router-dom';
+import { TestProvider } from 'test/helpers/TestProvider';
 import { selectOptionInTest } from 'test/helpers/selectOptionInTest';
 import { byLabelText, byPlaceholderText, byRole, byTestId, byText } from 'testing-library-selector';
 
@@ -17,7 +16,6 @@ import {
   AlertManagerDataSourceJsonData,
   AlertManagerImplementation,
 } from 'app/plugins/datasource/alertmanager/types';
-import { configureStore } from 'app/store/configureStore';
 import { AccessControlAction, ContactPointsState } from 'app/types';
 
 import 'whatwg-fetch';
@@ -28,6 +26,7 @@ import { AlertmanagersChoiceResponse } from './api/alertmanagerApi';
 import { discoverAlertmanagerFeatures } from './api/buildInfo';
 import { fetchNotifiers } from './api/grafana';
 import * as receiversApi from './api/receiversApi';
+import * as grafanaApp from './components/receivers/grafanaAppReceivers/grafanaApp';
 import {
   mockDataSource,
   MockDataSourceSrv,
@@ -69,19 +68,15 @@ const alertmanagerChoiceMockedResponse: AlertmanagersChoiceResponse = {
 };
 
 const renderReceivers = (alertManagerSourceName?: string) => {
-  const store = configureStore();
-
   locationService.push(
     '/alerting/notifications' +
       (alertManagerSourceName ? `?${ALERTMANAGER_NAME_QUERY_KEY}=${alertManagerSourceName}` : '')
   );
 
   return render(
-    <Provider store={store}>
-      <Router history={locationService.getHistory()}>
-        <Receivers />
-      </Router>
-    </Provider>
+    <TestProvider>
+      <Receivers />
+    </TestProvider>
   );
 };
 
@@ -100,9 +95,9 @@ const dataSources = {
 };
 
 const ui = {
-  newContactPointButton: byRole('link', { name: /new contact point/i }),
+  newContactPointButton: byRole('link', { name: /add contact point/i }),
   saveContactButton: byRole('button', { name: /save contact point/i }),
-  newContactPointTypeButton: byRole('button', { name: /new contact point type/i }),
+  newContactPointIntegrationButton: byRole('button', { name: /add contact point integration/i }),
   testContactPointButton: byRole('button', { name: /Test/ }),
   testContactPointModal: byRole('heading', { name: /test contact point/i }),
   customContactPointOption: byRole('radio', { name: /custom/i }),
@@ -149,6 +144,8 @@ const clickSelectOption = async (selectElement: HTMLElement, optionText: string)
 document.addEventListener('click', interceptLinkClicks);
 const emptyContactPointsState: ContactPointsState = { receivers: {}, errorCount: 0 };
 
+const useGetGrafanaReceiverTypeCheckerMock = jest.spyOn(grafanaApp, 'useGetGrafanaReceiverTypeChecker');
+
 describe('Receivers', () => {
   const server = setupServer();
 
@@ -164,6 +161,7 @@ describe('Receivers', () => {
   beforeEach(() => {
     server.resetHandlers();
     jest.resetAllMocks();
+    useGetGrafanaReceiverTypeCheckerMock.mockReturnValue(() => undefined);
     mocks.getAllDataSources.mockReturnValue(Object.values(dataSources));
     mocks.api.fetchNotifiers.mockResolvedValue(grafanaNotifiersMock);
     mocks.api.discoverAlertmanagerFeatures.mockResolvedValue({ lazyConfigInit: false });
@@ -409,7 +407,7 @@ describe('Receivers', () => {
     await byText(/Fields \(1\)/i).get(slackContainer);
 
     // add another channel
-    await userEvent.click(ui.newContactPointTypeButton.get());
+    await userEvent.click(ui.newContactPointIntegrationButton.get());
     await clickSelectOption(await byTestId('items.2.type').find(), 'Webhook');
     await userEvent.type(await ui.inputs.webhook.URL.find(), 'http://webhookurl');
 
